==> wao-ui-2.1-sources.jar: fr/ifremer/wao/ui/pages/Cartography.java <==
/*
 * #%L
 * Wao :: Web Interface
 * %%
 * Copyright (C) 2009 - 2010 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.wao.ui.pages;

import fr.ifremer.wao.bean.ConnectedUser;
import fr.ifremer.wao.bean.ContactFilter;
import fr.ifremer.wao.bean.ContactFilterImpl;
import fr.ifremer.wao.bean.UserRole;
import fr.ifremer.wao.bean.WaoFilter;
import fr.ifremer.wao.entity.Company;
import fr.ifremer.wao.service.ServiceSampling;
import fr.ifremer.wao.service.ServiceUser;
import fr.ifremer.wao.ui.data.FiltersModel;
import fr.ifremer.wao.ui.data.RequiresAuthentication;
import org.apache.tapestry5.Link;
import org.apache.tapestry5.annotations.InjectComponent;
import org.apache.tapestry5.annotations.Log;
import org.apache.tapestry5.annotations.Persist;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.corelib.components.Zone;
import org.apache.tapestry5.ioc.annotations.Inject;
import org.apache.tapestry5.ioc.services.PropertyAccess;
import org.apache.tapestry5.services.PageRenderLinkSource;
import org.nuiton.util.PeriodDates;
import org.slf4j.Logger;

import java.io.IOException;

/**
 * Created: 6 juil. 2010
 *
 * @author fdesbois <fdesbois@codelutin.com>
 * @version $Id: Cartography.java 1019 2011-02-16 16:25:34Z bleny $
 */
@RequiresAuthentication(allowedRoles = {UserRole.ADMIN, UserRole.COORDINATOR, UserRole.OBSERVER, UserRole.PROFESSIONAL})
public class Cartography {

    @SessionState
    @Property
    private ConnectedUser user;

    @Inject
    private Logger logger;

    @Inject
    private PageRenderLinkSource pageRender;

    @Inject
    private PropertyAccess propertyAccess;

    @Inject
    private ServiceUser serviceUser;

    @Inject
    private ServiceSampling serviceSampling;

    private String url;

    void setupRender() {
    }

    /**************************** FILTERS *************************************/

    @SessionState(create = false)
    private WaoFilter cartographyFilter;

    @Persist
    private FiltersModel<ContactFilter> filtersModel;

    public FiltersModel<ContactFilter> getFiltersModel() {
        if (filtersModel == null) {

            if (logger.isDebugEnabled()) {
                logger.debug("Initialize FiltersModel");
            }

            filtersModel = new FiltersModel<ContactFilter>(
                    propertyAccess, new ContactFilterImpl());

            filtersModel.setServiceUser(serviceUser);
            filtersModel.setServiceSampling(serviceSampling);
            filtersModel.setCompanyActive(true);

            // Initialize company
            if (user.isCoordinatorOrObserver()) {
                getFilter().setCompany(user.getCompany());
            }

            // Initialize period
            PeriodDates period = PeriodDates.createMonthsPeriodFromToday(-12);
            getFilter().setPeriod(period);

            getFilter().setObsProgram(user.getProfile().getObsProgram());

            // push in SessionState the filter
            cartographyFilter = getFilter();
        }
        return filtersModel;
    }

    public ContactFilter getFilter() {
        return getFiltersModel().getFilter();
    }

    public Company getCompany() {
        return getFilter().getCompany();
    }

    @InjectComponent
    private Zone samplingFilterZone;

    @InjectComponent
    private Zone sampleRowFilterZone;

    @Log
    Zone onValueChangedFromCompany(String companyId) {
        getFiltersModel().updateCompany(companyId);
        return samplingFilterZone;
    }

    @Log
    Zone onValueChangedFromProgramName(String programName) {
        getFiltersModel().updateProgram(programName);
        return sampleRowFilterZone;
    }

    void onSelectedFromReset() {
        filtersModel = null;
    }

//    void onSuccessFromFilters() {
//        if (!user.isAdmin()) {
//            throw new WaoException("Vous n'avez pas les droits nécessaires" +
//                    " pour filtrer sur une société", null);
//        }
//    }

    /**************************** URL *************************************/

    public String getUrl() throws IOException {
        if (url == null) {
            Link link = pageRender.createPageRenderLinkWithContext(
                                        KmlLoader.class,
                                        KmlLoader.StrategyValues.CONTACTS_STATES
            );
            url = link.toURI();
        }
        return url;
    }

    public String getTitle() {
        return "Contacts";
    }
}

==> wao-ui-2.1.4-sources.jar: fr/ifremer/wao/ui/pages/Cartography.java <==
/*
 * #%L
 * Wao :: Web Interface
 * %%
 * Copyright (C) 2009 - 2010 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.wao.ui.pages;

import fr.ifremer.wao.bean.ConnectedUser;
import fr.ifremer.wao.bean.ContactFilter;
import fr.ifremer.wao.bean.ContactFilterImpl;
import fr.ifremer.wao.bean.ObsProgram;
import fr.ifremer.wao.bean.UserRole;
import fr.ifremer.wao.bean.WaoFilter;
import fr.ifremer.wao.entity.Company;
import fr.ifremer.wao.service.ServiceSampling;
import fr.ifremer.wao.service.ServiceUser;
import fr.ifremer.wao.ui.data.FiltersModel;
import fr.ifremer.wao.ui.data.RequiresAuthentication;
import org.apache.tapestry5.Link;
import org.apache.tapestry5.annotations.InjectComponent;
import org.apache.tapestry5.annotations.Log;
import org.apache.tapestry5.annotations.Persist;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.corelib.components.Zone;
import org.apache.tapestry5.ioc.annotations.Inject;
import org.apache.tapestry5.ioc.services.PropertyAccess;
import org.apache.tapestry5.services.PageRenderLinkSource;
import org.nuiton.util.PeriodDates;
import org.slf4j.Logger;

import java.io.IOException;

/**
 * Created: 6 juil. 2010
 *
 * @author fdesbois <fdesbois@codelutin.com>
 * @version $Id: Cartography.java 1050 2011-03-02 13:11:44Z bleny $
 */
@RequiresAuthentication(allowedPrograms = {ObsProgram.OBSMER, ObsProgram.OBSVENTE}, allowedRoles = {UserRole.ADMIN, UserRole.COORDINATOR, UserRole.OBSERVER, UserRole.PROFESSIONAL})
public class Cartography {

    @SessionState
    @Property
    private ConnectedUser user;

    @Inject
    private Logger logger;

    @Inject
    private PageRenderLinkSource pageRender;

    @Inject
    private PropertyAccess propertyAccess;

    @Inject
    private ServiceUser serviceUser;

    @Inject
    private ServiceSampling serviceSampling;

    private String url;

    void setupRender() {
    }

    /**************************** FILTERS *************************************/

    @SessionState(create = false)
    private WaoFilter cartographyFilter;

    @Persist
    private FiltersModel<ContactFilter> filtersModel;

    public FiltersModel<ContactFilter> getFiltersModel() {
        if (filtersModel == null) {

            if (logger.isDebugEnabled()) {
                logger.debug("Initialize FiltersModel");
            }

            filtersModel = new FiltersModel<ContactFilter>(
                    propertyAccess, new ContactFilterImpl());

            filtersModel.setServiceUser(serviceUser);
            filtersModel.setServiceSampling(serviceSampling);
            filtersModel.setCompanyActive(true);

            // Initialize company
            if (user.isCoordinatorOrObserver()) {
                getFilter().setCompany(user.getCompany());
            }

            // Initialize period
            PeriodDates period = PeriodDates.createMonthsPeriodFromToday(-12);
            getFilter().setPeriod(period);

            getFilter().setObsProgram(user.getProfile().getObsProgram());

            // push in SessionState the filter
            cartographyFilter = getFilter();
        }
        return filtersModel;
    }

    public ContactFilter getFilter() {
        return getFiltersModel().getFilter();
    }

    public Company getCompany() {
        return getFilter().getCompany();
    }

    @InjectComponent
    private Zone samplingFilterZone;

    @InjectComponent
    private Zone sampleRowFilterZone;

    @Log
    Zone onValueChangedFromCompany(String companyId) {
        getFiltersModel().updateCompany(companyId);
        return samplingFilterZone;
    }

    @Log
    Zone onValueChangedFromProgramName(String programName) {
        getFiltersModel().updateProgram(programName);
        return sampleRowFilterZone;
    }

    void onSelectedFromReset() {
        filtersModel = null;
    }

//    void onSuccessFromFilters() {
//        if (!user.isAdmin()) {
//            throw new WaoException("Vous n'avez pas les droits nécessaires" +
//                    " pour filtrer sur une société", null);
//        }
//    }

    /**************************** URL *************************************/

    public String getUrl() throws IOException {
        if (url == null) {
            Link link = pageRender.createPageRenderLinkWithContext(
                                        KmlLoader.class,
                                        KmlLoader.StrategyValues.CONTACTS_STATES
            );
            url = link.toURI();
        }
        return url;
    }

    public String getTitle() {
        return "Contacts";
    }
}
